@@ -1,60 +1,28 @@
 use http::Uri;
 use log::*;
-use rustls::{ClientConfig, ClientSession, StreamOwned};
 use std::{
     net::{SocketAddr, TcpStream, ToSocketAddrs},
-    sync::Arc,
     thread,
     time::{self, Duration},
 };
 use tungstenite::{
-    client::{self, AutoStream, IntoClientRequest},
-    error::{TlsError, UrlError},
+    client::{uri_mode, IntoClientRequest},
+    client_tls,
+    error::UrlError,
     handshake::{client::Response, HandshakeError},
-    stream::{Mode, NoDelay, Stream as StreamSwitcher},
+    stream::{MaybeTlsStream, Mode, NoDelay},
     Error, Result, WebSocket,
 };
-use webpki::DNSNameRef;
 
-// copied from https://github.com/snapview/tungstenite-rs/blob/master/src/client.rs#L69
-fn wrap_stream(stream: TcpStream, domain: &str, mode: Mode) -> Result<AutoStream> {
-    match mode {
-        Mode::Plain => Ok(StreamSwitcher::Plain(stream)),
-        Mode::Tls => {
-            let config = {
-                let mut config = ClientConfig::new();
-                config
-                    .root_store
-                    .add_server_trust_anchors(&webpki_roots::TLS_SERVER_ROOTS);
-
-                Arc::new(config)
-            };
-            let domain = DNSNameRef::try_from_ascii_str(domain).map_err(TlsError::Dns)?;
-            let client = ClientSession::new(&config, domain);
-            let stream = StreamOwned::new(client, stream);
-
-            Ok(StreamSwitcher::Tls(stream))
-        }
-    }
-}
-
-// copied from https://github.com/snapview/tungstenite-rs/blob/master/src/client.rs#L206
-fn connect_to_some(
-    addrs: &[SocketAddr],
-    uri: &Uri,
-    mode: Mode,
-    timeout: Option<u64>,
-) -> Result<AutoStream> {
-    let domain = uri.host().ok_or(Error::Url(UrlError::NoHostName))?;
+// copied from https://github.com/snapview/tungstenite-rs/blob/master/src/client.rs#L122
+fn connect_to_some(addrs: &[SocketAddr], uri: &Uri, timeout: Option<u64>) -> Result<TcpStream> {
     for addr in addrs {
         debug!("Trying to contact {} at {}...", uri, addr);
-        if let Ok(raw_stream) = TcpStream::connect(addr) {
+        if let Ok(stream) = TcpStream::connect(addr) {
             if let Some(seconds) = timeout {
-                let _ = raw_stream.set_read_timeout(Some(Duration::from_secs(seconds)));
-            }
-            if let Ok(stream) = wrap_stream(raw_stream, domain, mode) {
-                return Ok(stream);
+                let _ = stream.set_read_timeout(Some(Duration::from_secs(seconds)));
             }
+            return Ok(stream);
         }
     }
     Err(Error::Url(UrlError::UnableToConnect(uri.to_string())))
@@ -65,11 +33,11 @@ fn connect_to_some(
 fn connect_with_timeout(
     url: &str,
     timeout: Option<u64>,
-) -> Result<(WebSocket<AutoStream>, Response)> {
+) -> Result<(WebSocket<MaybeTlsStream<TcpStream>>, Response)> {
     let request = url.into_client_request()?;
 
     let uri = request.uri();
-    let mode = client::uri_mode(uri)?;
+    let mode = uri_mode(uri)?;
     let host = request
         .uri()
         .host()
@@ -79,9 +47,11 @@ fn connect_with_timeout(
         Mode::Tls => 443,
     });
     let addrs = (host, port).to_socket_addrs()?;
-    let mut stream = connect_to_some(addrs.as_slice(), request.uri(), mode, timeout)?;
+    let mut stream = connect_to_some(addrs.as_slice(), request.uri(), timeout)?;
     NoDelay::set_nodelay(&mut stream, true)?;
-    tungstenite::client(request, stream).map_err(|e| match e {
+    let client = client_tls(request, stream);
+
+    client.map_err(|e| match e {
         HandshakeError::Failure(f) => f,
         HandshakeError::Interrupted(_) => panic!("Bug: blocking handshake not blocked"),
     })
@@ -89,7 +59,10 @@ fn connect_with_timeout(
 
 // This function is equivalent to tungstenite::connect(), with an additional benefit that
 // it can make read_message() timeout after 5 seconds
-pub(super) fn connect_with_retry(url: &str, timeout: Option<u64>) -> WebSocket<AutoStream> {
+pub(super) fn connect_with_retry(
+    url: &str,
+    timeout: Option<u64>,
+) -> WebSocket<MaybeTlsStream<TcpStream>> {
     let max_count = 5;
     let mut backoff_factor = 1;
     let backoff_duration = time::Duration::from_secs(if url.contains("bitmex") { 16 } else { 4 });
