@@ -11,7 +11,7 @@ mod bybit_inverse_future {
         gen_test_code!(
             BybitInverseFutureWSClient,
             subscribe,
-            &vec!["trade.BTCUSDZ21".to_string()]
+            &vec!["trade.BTCUSDM22".to_string()]
         );
     }
 
@@ -20,7 +20,7 @@ mod bybit_inverse_future {
         gen_test_code!(
             BybitInverseFutureWSClient,
             subscribe,
-            &vec![r#"{"op":"subscribe","args":["trade.BTCUSDZ21"]}"#.to_string()]
+            &vec![r#"{"op":"subscribe","args":["trade.BTCUSDM22"]}"#.to_string()]
         );
     }
 
@@ -29,7 +29,7 @@ mod bybit_inverse_future {
         gen_test_code!(
             BybitInverseFutureWSClient,
             subscribe_trade,
-            &vec!["BTCUSDZ21".to_string()]
+            &vec!["BTCUSDM22".to_string()]
         );
     }
 
@@ -38,7 +38,7 @@ mod bybit_inverse_future {
         gen_test_code!(
             BybitInverseFutureWSClient,
             subscribe_orderbook,
-            &vec!["BTCUSDZ21".to_string()]
+            &vec!["BTCUSDM22".to_string()]
         );
     }
 
@@ -47,7 +47,7 @@ mod bybit_inverse_future {
         gen_test_code!(
             BybitInverseFutureWSClient,
             subscribe_ticker,
-            &vec!["BTCUSDZ21".to_string()]
+            &vec!["BTCUSDM22".to_string()]
         );
     }
 
@@ -55,11 +55,11 @@ mod bybit_inverse_future {
     fn subscribe_candlestick() {
         gen_test_subscribe_candlestick!(
             BybitInverseFutureWSClient,
-            &vec![("BTCUSDZ21".to_string(), 60)]
+            &vec![("BTCUSDM22".to_string(), 60)]
         );
         gen_test_subscribe_candlestick!(
             BybitInverseFutureWSClient,
-            &vec![("BTCUSDZ21".to_string(), 2592000)]
+            &vec![("BTCUSDM22".to_string(), 2592000)]
         );
     }
 }
